# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""move images out of subdirs

Revision ID: 42723a9dd85c
Revises: 01de4f42cf27
Create Date: 2021-09-13 13:52:28.908485

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "42723a9dd85c"
down_revision = "01de4f42cf27"
branch_labels = None
depends_on = None

script_content = """#!/bin/sh
set -o errexit

export HOME=$TMPDIR

{{#need_data}}
./framework.sh -r .
chmod 770 .
cd rawdata/
../productfetcher{{product_locator}} {{^single_image}}&{{/single_image}}

image_subdirs=$(ls)

for i in $image_subdirs; do
  if [[ -d "./$i" ]]; then
    mv "./$i"/* .
    rm -rf "./$i"
  fi
done

.{{/need_data}}./carta_envoy {{#need_data}}--parallel{{/need_data}} {{#single_image}}--single -i {{imageName}}{{/single_image}} -d $1 -n $2 -wf $3 -r $4
{{#need_data}}wait{{/need_data}}

"""


old_content = """#!/bin/sh
set -o errexit

export HOME=$TMPDIR

{{#need_data}}
./framework.sh -r .
chmod 770 .
cd rawdata/
../productfetcher{{product_locator}} {{^single_image}}&{{/single_image}}
.{{/need_data}}./carta_envoy {{#need_data}}--parallel{{/need_data}} {{#single_image}}--single -i {{imageName}}{{/single_image}} -d $1 -n $2 -wf $3 -r $4
{{#need_data}}wait{{/need_data}}

"""


def upgrade():
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{script_content}' where filename='carta.sh'
        """
    )


def downgrade():
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{old_content}' where filename='carta.sh'
        """
    )
