# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""correct calibration state machine

Revision ID: baf4d187d454
Revises: 491d1dbafa67
Create Date: 2021-12-21 14:57:54.222820

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "baf4d187d454"
down_revision = "491d1dbafa67"
branch_labels = None
depends_on = None


def upgrade():
    op.execute(
        f"""
        INSERT INTO capability_state_transitions (capability_name, from_state, pattern, to_state) 
        VALUES ('std_calibration', 'Awaiting QA', 'type == qa-complete', 'Failed') 
        """
    )
    op.execute(
        f"""
        UPDATE capability_state_transitions 
        SET pattern='type == ingestion-complete' 
        WHERE from_state='Ingesting' AND to_state='Complete' AND capability_name='std_calibration'
        """
    )
    op.execute(
        f"""
        UPDATE capability_state_transitions 
        SET pattern='type == ingestion-failed' 
        WHERE from_state='Ingesting' AND to_state='Error' AND capability_name='std_calibration'
        """
    )


def downgrade():
    op.execute(
        f"""
        DELETE FROM capability_state_transitions 
        WHERE capability_name='std_calibration' AND pattern='type == qa-complete'
        """
    )
    op.execute(
        f"""
        UPDATE capability_state_transitions 
        SET pattern='type == workflow-complete' 
        WHERE from_state='Ingesting' AND to_state='Complete' AND capability_name='std_calibration'
        """
    )
    op.execute(
        f"""
        UPDATE capability_state_transitions 
        SET pattern='type == workflow-failed' 
        WHERE from_state='Ingesting' AND to_state='Error' AND capability_name='std_calibration'
        """
    )
